rm(list=ls())  # remove any datasets that may still be in RStudio

setwd("C:/Users/Tamara/Documents/R") # set working directory
dir()     #show contents of working directory - can be used to copy and paste file names

data <- read.csv("BRSmart2016only-simplified.csv",header = T) # read in .csv file
head(data)   # show header - can be used to check of all variables read in
data <- data[-c(168:194), ]  #remove 'extra' rows - artifact of R reading tabs that cannot be seen
data = droplevels(data)
str(data)
table(data$WUP_Code)
data$BR_within_FUA = as.factor(data$RevWithinFUA)
data$MultiFUA = as.factor(data$MultiFUA)
data$ForeignFUA = as.factor(data$ForeignFUA)
data$Transbdy = as.factor(data$Transbdy)
data$Capital_in = as.factor(data$Capital_in)
data$Offshore = as.factor(data$Offshore)
data$NEAR_FID = as.factor(data$NEAR_FID)

FID_logical = ifelse (is.finite(data$NEAR_FID),"Y","N") #makes a binary variable describing 
                                                        #if there is a Natura 2000 site near centroid
data = data.frame(data,FID_logical)

head(data)
names(data) #gives all the variable names - shows that columns 20 -23 are the colums of interest
data$lastrev = apply(data[,20:23],1,max,na.rm=T) # apply a function to a dataframe
# in this case max function to the rows (1) not columns (2) for the columns 20:23 

log_area <- log(as.numeric(data$BR_Area_ha)) #create a variable containing the natural logarithm of area
#create a variable containing the logarithm base 10 of area
log_pop <- log10(data$RevFUAPop)
log_dist <- log(data$RevDistFUAbdy+1) #need to add 1 to the distance because zero gives infinity log

plot(data$LatDD,log_area)
plot(data$LatDD,log_pop)
plot(data$LatDD,log_dist)
plot(data$LongDD,log_area)
plot(data$LongDD,log_pop)
plot(data$LongDD,log_dist)
boxplot(log_area~data$WUP_Code)
boxplot(log_pop~data$WUP_Code)
boxplot(log_dist~data$WUP_Code)
range(data$RevDistFUAbdy)
range(log_dist)

table(data$FID_logical,data$RevWithinFUA)


plot(density(log10(data$RevDistFUAbdy)), main ="", xlab = "")
plot(density(Log10(data$RevDistFUAbdy)), main ="", xlab = "")
title(xlab = "Log10(Distance to FUA boundary) km")
table(data$UGS_BR)
#data$UGS_BR = gsub("N ","N",data$UGS_BR) # this did not work it replaced the whole variable with N

m1 <- lm(log_area ~ factor(data$WUP_Code)*data$lastrev*data$RevDistFUAbdy)

summary(m1)  # the interactions of explanatory variables don't seem to be significant
m2 <- lm(log_area~ factor(data$WUP_Code)+data$lastrev+data$RevDistFUAbdy)

summary(m2)  # this is the model I put in the manuscript (area of biosphere depends 
#               on Wup_region and last review, but not distance to FUA)
plot(log_area,data$lastrev)


m3 <- lm(log_area~ factor(data$WUP_Code)*data$lastrev)
summary(m3)

dir()
country <- read.csv("country-fua-rev.csv",header = T) # read in .csv file
head(country)   # show header - can be used to check of all variables read in

m1 <- lm(country$Percent.in.FUA.by.country ~ factor(country$WUP_region))

summary(m1)  # output shows that there is no significant difference between the retions
boxplot(country$Number.of.Biospheres.in.FUA.s~country$WUP_region)
str(data)

log_pop <- log(data$RevFUAPop) #create a variable containing the natural logarithm of population

m4 <- lm(log_pop ~ factor(data$WUP_Code)*data$lastrev*data$RevDistFUAbdy)

summary(m4) # shows that interactions are not siginficant

m5 <- lm(log_pop~ factor(data$WUP_Code)+data$lastrev+data$RevDistFUAbdy)

summary(m5)

m6 <- lm(log_pop~ data$WUP_Code+data$RevDistFUAbdy)

summary(m6)

m6 <- lm(log_pop~log_dist)

summary(m6)  # there is a negative correlation between log(FUA pop) and log(dist)
plot(log_pop,log_dist) # but very hard to see in the data - not an important trend


boxplot(data$RevFUAPop~data$RevWithinFUA)
m7 <- aov(data$RevFUAPop~data$RevWithinFUA)

summary(m7) # shows that population in FUAs that are overlapping with BRs are larger

m8 <- lm(log_pop~data$lastrev)

summary(m8)  # there is no correlation between log(FUA pop) and last review
plot(log_pop,data$lastrev)


m1 <- aov(log_area~data$WUP_Code)
summary(m1)
boxplot((log_area~data$WUP_Code))
